From 81729203dd7fc7c4e4c624908f172e1820751339 Mon Sep 17 00:00:00 2001
From: Hirofumi Katayama <katayama.hirofumi.mz@gmail.com>
Date: Sat, 16 Nov 2019 14:46:42 +0900
Subject: [PATCH] user32: Loose message box font check.

Compare TEXTMETRICW rather than LOGFONTW.

Signed-off-by: Hirofumi Katayama <katayama.hirofumi.mz@gmail.com>
---
 dlls/user32/tests/dialog.c | 36 +++++++++++++++++++++++++++++++-----
 1 file changed, 31 insertions(+), 5 deletions(-)

diff --git a/dlls/user32/tests/dialog.c b/dlls/user32/tests/dialog.c
index b72f08816d..a8187d6143 100644
--- a/dlls/user32/tests/dialog.c
+++ b/dlls/user32/tests/dialog.c
@@ -1958,8 +1958,10 @@ static void test_MessageBoxFontTest(void)
 
     HWND hDlg;
     HFONT hFont;
-    LOGFONTW lfStaticFont;
     NONCLIENTMETRICSW ncMetrics;
+    HDC hdc;
+    HFONT hFont2;
+    TEXTMETRICW tm1, tm2;
 
     /* Check if the dialog can be created from the template. On Win9x, this should fail
      * because we are calling the W function which is not implemented, but that's what
@@ -1980,13 +1982,37 @@ static void test_MessageBoxFontTest(void)
         DestroyWindow(hDlg);
         return;
     }
-    GetObjectW(hFont, sizeof(LOGFONTW), &lfStaticFont);
 
     ncMetrics.cbSize = FIELD_OFFSET(NONCLIENTMETRICSW, iPaddedBorderWidth);
     SystemParametersInfoW(SPI_GETNONCLIENTMETRICS, 0, &ncMetrics, 0);
-    ok( !memcmp(&lfStaticFont, &ncMetrics.lfMessageFont, FIELD_OFFSET(LOGFONTW, lfFaceName)) &&
-        !lstrcmpW(lfStaticFont.lfFaceName, ncMetrics.lfMessageFont.lfFaceName),
-        "dialog doesn't use message box font\n");
+
+    hFont2 = CreateFontIndirectW(&ncMetrics.lfMessageFont);
+    if (!hFont2)
+    {
+        skip("hFont2 is NULL\n");
+        DestroyWindow(hDlg);
+        return;
+    }
+
+    hdc = CreateCompatibleDC(NULL);
+    if (!hdc)
+    {
+        skip("hdc is NULL\n");
+        DeleteObject(hFont2);
+        DestroyWindow(hDlg);
+        return;
+    }
+
+    SelectObject(hdc, hFont);
+    GetTextMetricsW(hdc, &tm1);
+
+    SelectObject(hdc, hFont2);
+    GetTextMetricsW(hdc, &tm2);
+
+    DeleteDC(hdc);
+    DeleteObject(hFont2);
+
+    ok(!memcmp(&tm1, &tm2, sizeof(tm1)), "dialog doesn't use message box font\n");
     DestroyWindow(hDlg);
 }
 
-- 
2.23.0

